#!/bin/tcsh

### This script takes all the results from the regression
### analyses and collates their review summaries into tables.
### The tables (one for each stim+blur) combination have
### one row per subject, and show information about the
### number of time points censored, etc.
### The tables get the suffix '.xls', but are really plain
### text files, which can be opened with Excel.

set site = Beijing
set nsub = `wc -l < $site.list.txt`

# loop over stims and blurs

foreach stim ( blk10 blk30 evran evreg )
foreach blur ( 4 6 8 10 )

# output directory with the subject results
  set wdir = ../${stim}stim.b${blur}mm
  if( ! -d $wdir )then
     echo "-- skipping $stim $blur -- directory $wdir does not exist"
     continue
  endif

# how many subject results found?
  set nres = `find $wdir -name sub\*.results | wc -l`
  if( $nres == 0 )then
    echo "-- skipping $stim $blur -- directory $wdir has no subject results"
    continue
  endif
  if( $nres < $nsub )then
    echo "-- WARNING $stim $blur -- directory $wdir has only $nres results instead of $nsub"
  endif

# make the table
  gen_ss_review_table.py                            \
    -infiles $wdir/sub*.results/out.ss_review.*.txt \
    -tablefile ${stim}stim.b${blur}mm.xls           \
    -overwrite

# tell the user what happened
  if( -f ${stim}stim.b${blur}mm.xls )then
    echo "++ Created table file ${stim}stim.b${blur}mm.xls"
  else
    echo "-- ERROR $stim $blur -- failed to create table file ${stim}stim.b${blur}mm.xls"
  endif

end
end

exit 0
