#!/bin/tcsh

### This script counts the 'hitmaps' output by the 1-sample
### t-tests and produces an output table with lots of results.

pushd ..

# This determines that we are looking at the 1-sample results
set odir = TT.20.20

# prefixes of filenames for hitmaps
set pref = ( X       C       D       E       F       G       )
# corresponding output code in the table
set type = ( TT+ETAC TT+CSim TT+ACFr TT+FWHr TT+ACFs TT+FWHs )

# P'xxx's'y' is for p-value = 0.xxx and sideness of t-test = y

set case = ( P010s1 P010s2 \
             P005s1 P005s2 \
             P002s1 P002s2 \
             P001s1 P001s2  )

# count how many prefixes and how many cases

set npref = ( `count -dig 1 1 $#pref` )
set ncase = ( `count -dig 1 1 $#case` )

# loops over stimuli and blurs

foreach stim ( blk10 blk30 evreg evran )
foreach blur ( 4 6 8 10 )

  set fred = ${stim}stim.b${blur}mm
  if( ! -d $fred/$odir )then
    echo "skip $fred -- no $fred/$odir" ; continue
  endif
  cd $fred/$odir
  set ntry = `find . -maxdepth 1 -name 'C.????.nii.gz' | wc -l`
  if( $ntry < 100 )then
    echo "skip $fred -- ntry=$ntry" ; cd ../.. ; continue
  endif
# loop over prefixes (type of cluster-threshold method)
  foreach tt ( $npref )
# loop over cases (p-values and sideness)
  foreach cc ( $ncase )
    set ntot = `find . -maxdepth 1 -name "$pref[$tt].????.$case[$cc].hitmap.nii.gz" | wc -l`
# cdf2stat stuff gives the 95% binomial confidence interval for the estimated percentage
    echo $stim ${blur}mm $type[$tt] $case[$cc] :: ntot=$ntot ntry=$ntry  \
            `ccalc "100*$ntot/$ntry"`%                                   \
         CI `ccalc "100*cdf2stat(.025,7,0.5+$ntot,0.5+$ntry-$ntot,0)"`%  \
            `ccalc "100*cdf2stat(.975,7,0.5+$ntot,0.5+$ntry-$ntot,0)"`% 
  end
  end
  cd ../..
end
end

popd
