# script to generate a 3dttest++ command using pre-computed
# results from the FCon1000 collection

# do not run this file in a separate shell via 'tcsh'!
# instead, source this file, with the following variable pre-set
#
#   odir    = output directory                           MANDATORY
#   sdir    = source directory                           MANDATORY
#   mask    = mask dataset                               MANDATORY
#   prefix  = prefix for output files                    MANDATORY
#   Slist   = ( list of five digit subject IDs )         MANDATORY
#   Anum    = number of subjects for setA                MANDATORY
#   Bnum    = number of subjects for setB                OPTIONAL
#   Olist   = ( other options to 3dttest++ )             OPTIONAL
#   tempdir = temporary directory (for 3dXClustSim)      OPTIONAL
#   seed    = seed for random numbers                    OPTIONAL
#
# output is the variable ttcmd, which can be executed
# to run the program as desired
#
# *** you need to have done 'set noglob' before running   ***
# *** this script and before running the command '$ttcmd' ***

set ttcmd = ( 3dttest++ -DAFNI_DONT_LOGFILE=YES -toz -AminusB -mask $mask )
set ttcmd = ( $ttcmd -prefix $odir/$prefix.nii.gz )
if( $?tempdir ) set ttcmd = ( $ttcmd -tempdir $tempdir )

if( $?Olist )then
  set ttcmd = ( $ttcmd $Olist )
endif

if( $?Bnum == 0 )then
  set Bnum = 0
else
  if( $Bnum < 10 ) set Bnum = 0
endif

if( $?Alist == 0 || $?Blist == 0 )then
  set need_lists = 1
  set Alist = ( )
  set Blist = ( )
  set snum  = $Anum
  if( $Bnum > 9 ) @ snum = $snum + $Bnum
else
  @ snum = $#Alist + $#Blist
  set need_lists = 0
endif

if( $?seed == 0 ) set seed = 0

if( $need_lists )then
  set clist = ( `count -seed $seed -dig 1 1 $#Slist S$snum` )
  foreach sss ( `count -dig 1 1 $Anum` )
    set aaa = $clist[$sss]
    set Alist = ( $Alist $Slist[$aaa] )
  end
  if( $Bnum > 9 )then
    @ bot = $Anum + 1
    foreach sss ( `count -dig 1 $bot $snum` )
      set aaa = $clist[$sss]
      set Blist = ( $Blist $Slist[$aaa] )
    end
  endif
endif

set ttcmd = ( $ttcmd -setA setA )
foreach aaa ( $Alist )
  set subd = $sdir/${aaa}.results
  set ttcmd = ( $ttcmd $aaa $subd/stats.${aaa}_REML+tlrc.HEAD\'\[1\]\' )
end

if( $#Blist > 1 )then
  set ttcmd = ( $ttcmd -setB setB )
  foreach aaa ( $Blist )
    set subd = $sdir/${aaa}.results
    set ttcmd = ( $ttcmd $aaa $subd/stats.${aaa}_REML+tlrc.HEAD\'\[1\]\' )
  end
endif

if( $need_lists )then
  set TTlist = ( $Alist $Blist )
endif
