#!/bin/tcsh

# This script submits the jobs for the time series regression
# of each individual subject's data, for one stim type.
# It uses the 'swarm' command, which is part of the Linux cluster
# management system SLURM.

unset noclobber
set site = Beijing

# stim name     ( blk10       blk30       evran   evreg   )
set stim = "blk30"
# stim response ( BLOCK(10,1) BLOCK(30,1) dmBLOCK dmBLOCK )
set resp = '"BLOCK(30,1)"'
# which Script file to use (2B for block, 2E for event)
set case = 2B

# subject ID list
set Slist = ( `cat $site.list.txt` )

# Loop over blurs
# Note: you may not be able to submit all these jobs at once,
#       depending on the limitations of your cluster.
#       In that case, you can try running one stim class at a time.

foreach blur ( 4 6 8 10 )

# create a file, with 1 line for each case to run
  set sname = junk.swarm.$stim.b${blur}mm.regress
  if( -f $sname ) \rm $sname
  touch $sname

  foreach sub ( $Slist )
    echo "tcsh Script_${case}.regress.csh ${stim}stim.$site.txt $resp $blur $sub" >> $sname
  end

# run this file via swarm (16 threads per job)
# the 'nimh' and 'quick' partitions are local to NIH,
# and certainly have to be changed for any other site

  swarm -f $sname -g 12 -t 16 -b 1 --usecsh --time 1:59:00 \
      --partition nimh,quick --job-name Rbk30

# let that job get going before submitting another one
  sleep 20
end

exit 0
