#!/bin/tcsh

# This script submits the jobs for the 1-sample t-test simulations.
# It uses the 'swarm' command, which is part of the Linux cluster
# management system SLURM.

unset noclobber

# number of cases to run (1..9999)
set ncase = 1000
# max number of jobs to run at once
set njob  = 200
# batching parameter for SLURM
@ nbat = $ncase / $njob
if( $nbat < 1 ) set nbat = 1

# Loop over stimuli and blurs
# Note: you may not be able to submit all these jobs at once,
#       depending on the limitations of your cluster.
#       In that case, you can try running one stim class at a time.

foreach stim ( blk10 blk30 evran evreg )
foreach blur ( 4 6 8 10 )

# create a file, with 1 line for each case to run
  set sname = junk.swarm.$stim.b${blur}mm.ttest.2sam
  if( -f $sname ) \rm $sname
  touch $sname

  foreach ccc ( `count -dig 4 1 $ncase` )
    echo "tcsh Script_3B.ttest.2sam.csh $stim $blur $ccc" >> $sname
  end

# run this file via swarm (16 threads per job)
# the 'nimh' and 'quick' partitions are local to NIH,
# and certainly have to be changed for any other site

  swarm -f $sname -g 12 -t 16 -b $nbat --usecsh --time 1:59:00 \
      --partition nimh,quick --job-name TT2sam --sbatch '--gres=lscratch:50'

# let that job get going before submitting another one
  sleep 20
end
end
